@@ -5,7 +5,7 @@ use httpdate::HttpDate;
 use reqwest::{header::DATE, Client};
 use sha2::{Digest, Sha256};
 
-async fn request(config: Config) -> Result<(), Box<dyn std::error::Error>> {
+async fn request(config: Config) -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
     let digest = Sha256::new();
 
     let client = Client::new();
@@ -28,15 +28,17 @@ async fn request(config: Config) -> Result<(), Box<dyn std::error::Error>> {
 }
 
 #[tokio::main]
-async fn main() -> Result<(), Box<dyn std::error::Error>> {
+async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
     std::env::set_var("RUST_LOG", "info");
     pretty_env_logger::init();
 
-    let config = Config::default().require_header("accept");
+    tokio::spawn(async move {
+        let config = Config::default().require_header("accept");
 
-    request(config.clone()).await?;
-    request(config.mastodon_compat()).await?;
-    Ok(())
+        request(config.clone()).await?;
+        request(config.mastodon_compat()).await
+    })
+    .await?
 }
 
 #[derive(Debug, thiserror::Error)]
