@@ -29,11 +29,11 @@ pub trait SignExt: Sign {
         digest: D,
         v: V,
         f: F,
-    ) -> Pin<Box<dyn Future<Output = Result<Request, E>>>>
+    ) -> Pin<Box<dyn Future<Output = Result<Request, E>> + Send>>
     where
         F: FnOnce(&str) -> Result<String, E> + Send + 'static,
         E: From<SignError> + From<reqwest::Error>,
-        K: Display + 'static,
+        K: Display + Send + 'static,
         D: DigestCreate + Send + 'static,
         V: AsRef<[u8]> + Into<Body> + Send + 'static,
         Self: Sized;
@@ -45,11 +45,11 @@ pub trait SignExt: Sign {
         digest: D,
         v: V,
         f: F,
-    ) -> Pin<Box<dyn Future<Output = Result<Request, E>>>>
+    ) -> Pin<Box<dyn Future<Output = Result<Request, E>> + Send>>
     where
         F: FnOnce(&str) -> Result<String, E> + Send + 'static,
         E: From<SignError> + From<reqwest::Error>,
-        K: Display + 'static,
+        K: Display + Send + 'static,
         D: DigestCreate + Send + 'static,
         V: AsRef<[u8]> + Into<Body> + Send + 'static,
         Self: Sized;
@@ -63,11 +63,11 @@ impl SignExt for RequestBuilder {
         mut digest: D,
         v: V,
         f: F,
-    ) -> Pin<Box<dyn Future<Output = Result<Request, E>>>>
+    ) -> Pin<Box<dyn Future<Output = Result<Request, E>> + Send>>
     where
         F: FnOnce(&str) -> Result<String, E> + Send + 'static,
         E: From<SignError> + From<reqwest::Error>,
-        K: Display + 'static,
+        K: Display + Send + 'static,
         D: DigestCreate + Send + 'static,
         V: AsRef<[u8]> + Into<Body> + Send + 'static,
         Self: Sized,
@@ -97,11 +97,11 @@ impl SignExt for RequestBuilder {
         mut digest: D,
         v: V,
         f: F,
-    ) -> Pin<Box<dyn Future<Output = Result<Request, E>>>>
+    ) -> Pin<Box<dyn Future<Output = Result<Request, E>> + Send>>
     where
         F: FnOnce(&str) -> Result<String, E> + Send + 'static,
         E: From<SignError> + From<reqwest::Error>,
-        K: Display + 'static,
+        K: Display + Send + 'static,
         D: DigestCreate + Send + 'static,
         V: AsRef<[u8]> + Into<Body> + Send + 'static,
         Self: Sized,
@@ -140,11 +140,11 @@ mod middleware {
             mut digest: D,
             v: V,
             f: F,
-        ) -> Pin<Box<dyn Future<Output = Result<Request, E>>>>
+        ) -> Pin<Box<dyn Future<Output = Result<Request, E>> + Send>>
         where
             F: FnOnce(&str) -> Result<String, E> + Send + 'static,
             E: From<SignError> + From<reqwest::Error>,
-            K: Display + 'static,
+            K: Display + Send + 'static,
             D: DigestCreate + Send + 'static,
             V: AsRef<[u8]> + Into<Body> + Send + 'static,
             Self: Sized,
@@ -174,11 +174,11 @@ mod middleware {
             mut digest: D,
             v: V,
             f: F,
-        ) -> Pin<Box<dyn Future<Output = Result<Request, E>>>>
+        ) -> Pin<Box<dyn Future<Output = Result<Request, E>> + Send>>
         where
             F: FnOnce(&str) -> Result<String, E> + Send + 'static,
             E: From<SignError> + From<reqwest::Error>,
-            K: Display + 'static,
+            K: Display + Send + 'static,
             D: DigestCreate + Send + 'static,
             V: AsRef<[u8]> + Into<Body> + Send + 'static,
             Self: Sized,
